@@ -492,6 +492,7 @@ Optionally accepts the following attributes:
 * `stable`: Corresponds to [`STABLE`](https://www.postgresql.org/docs/current/sql-createfunction.html).
 * `volatile`: Corresponds to [`VOLATILE`](https://www.postgresql.org/docs/current/sql-createfunction.html).
 * `raw`: Corresponds to [`RAW`](https://www.postgresql.org/docs/current/sql-createfunction.html).
+* `support`: Corresponds to [`SUPPORT`](https://www.postgresql.org/docs/current/sql-createfunction.html) and is the Rust path to a function to act as the SUPPORT function
 * `security_definer`: Corresponds to [`SECURITY DEFINER`](https://www.postgresql.org/docs/current/sql-createfunction.html)
 * `security_invoker`: Corresponds to [`SECURITY INVOKER`](https://www.postgresql.org/docs/current/sql-createfunction.html)
 * `parallel_safe`: Corresponds to [`PARALLEL SAFE`](https://www.postgresql.org/docs/current/sql-createfunction.html).
@@ -1081,6 +1082,12 @@ fn impl_guc_enum(ast: DeriveInput) -> syn::Result<proc_macro2::TokenStream> {
         Hidden(bool),
     }
 
+    impl GucEnumAttribute {
+        fn is_guc_enum_attribute(attribute: &str) -> bool {
+            matches!(attribute, "name" | "hidden")
+        }
+    }
+
     impl Parse for GucEnumAttribute {
         fn parse(input: syn::parse::ParseStream) -> syn::Result<Self> {
             let ident: Ident = input.parse()?;
@@ -1110,17 +1117,26 @@ fn impl_guc_enum(ast: DeriveInput) -> syn::Result<proc_macro2::TokenStream> {
         let mut name = None;
         let mut hidden = None;
         for attr in variant.attrs.iter() {
-            let tokens = attr.meta.require_name_value()?.to_token_stream();
-            let pair: GucEnumAttribute = syn::parse2(tokens)?;
-            match pair {
-                GucEnumAttribute::Name(value) => {
-                    if name.replace(value).is_some() {
-                        return Err(syn::Error::new(ast.span(), "too many #[name] attributes"));
-                    }
-                }
-                GucEnumAttribute::Hidden(value) => {
-                    if hidden.replace(value).is_some() {
-                        return Err(syn::Error::new(ast.span(), "too many #[hidden] attributes"));
+            if let Some(ident) = attr.path().get_ident() {
+                if GucEnumAttribute::is_guc_enum_attribute(&ident.to_string()) {
+                    let pair: GucEnumAttribute = syn::parse2(attr.meta.to_token_stream())?;
+                    match pair {
+                        GucEnumAttribute::Name(value) => {
+                            if name.replace(value).is_some() {
+                                return Err(syn::Error::new(
+                                    ast.span(),
+                                    "too many #[name] attributes",
+                                ));
+                            }
+                        }
+                        GucEnumAttribute::Hidden(value) => {
+                            if hidden.replace(value).is_some() {
+                                return Err(syn::Error::new(
+                                    ast.span(),
+                                    "too many #[hidden] attributes",
+                                ));
+                            }
+                        }
                     }
                 }
             }
