@@ -667,7 +667,7 @@ impl Pgrx {
     pub fn home() -> Result<PathBuf, PgrxHomeError> {
         let pgrx_home = std::env::var("PGRX_HOME").map_or_else(
             |_| {
-                let mut pgrx_home = match home::home_dir() {
+                let mut pgrx_home = match std::env::home_dir() {
                     Some(home) => home,
                     None => return Err(PgrxHomeError::NoHomeDirectory),
                 };
@@ -711,16 +711,7 @@ pub fn SUPPORTED_VERSIONS() -> Vec<PgVersion> {
         PgVersion::new(15, PgMinorVersion::Latest, None),
         PgVersion::new(16, PgMinorVersion::Latest, None),
         PgVersion::new(17, PgMinorVersion::Latest, None),
-        PgVersion::new(
-            18,
-            PgMinorVersion::Beta(2),
-            Some(
-                Url::parse(
-                    "https://ftp.postgresql.org/pub/source/v18beta2/postgresql-18beta2.tar.bz2",
-                )
-                .expect("malformed pg18beta2 url"),
-            ),
-        ),
+        PgVersion::new(18, PgMinorVersion::Latest, None),
     ]
 }
 
