@@ -144,8 +144,7 @@ fn nonzero_thread_id() -> NonZeroUsize {
         static BYTE: u8 = const { 0 };
     }
     BYTE.with(|p: &u8| {
-        // Note: Avoid triggering the `unstable_name_collisions` lint.
-        let addr = sptr::Strict::addr(p as *const u8);
+        let addr = (p as *const u8).addr();
         // SAFETY: `&u8` is always nonnull, so its address is always nonzero.
         unsafe { NonZeroUsize::new_unchecked(addr) }
     })
