@@ -178,7 +178,7 @@ impl ToSql for PgAggregateEntity {
 
         if let Some(value) = self.finalfunc {
             optional_attributes.push((
-                format!("\tFINALFUNC = {}\"{}\"", schema, value),
+                format!("\tFINALFUNC = {schema}\"{value}\""),
                 format!("/* {}::final */", self.full_path),
             ));
         }
@@ -190,43 +190,43 @@ impl ToSql for PgAggregateEntity {
         }
         if let Some(value) = self.combinefunc {
             optional_attributes.push((
-                format!("\tCOMBINEFUNC = {}\"{}\"", schema, value),
+                format!("\tCOMBINEFUNC = {schema}\"{value}\""),
                 format!("/* {}::combine */", self.full_path),
             ));
         }
         if let Some(value) = self.serialfunc {
             optional_attributes.push((
-                format!("\tSERIALFUNC = {}\"{}\"", schema, value),
+                format!("\tSERIALFUNC = {schema}\"{value}\""),
                 format!("/* {}::serial */", self.full_path),
             ));
         }
         if let Some(value) = self.deserialfunc {
             optional_attributes.push((
-                format!("\tDESERIALFUNC ={} \"{}\"", schema, value),
+                format!("\tDESERIALFUNC ={schema} \"{value}\""),
                 format!("/* {}::deserial */", self.full_path),
             ));
         }
         if let Some(value) = self.initcond {
             optional_attributes.push((
-                format!("\tINITCOND = '{}'", value),
+                format!("\tINITCOND = '{value}'"),
                 format!("/* {}::INITIAL_CONDITION */", self.full_path),
             ));
         }
         if let Some(value) = self.msfunc {
             optional_attributes.push((
-                format!("\tMSFUNC = {}\"{}\"", schema, value),
+                format!("\tMSFUNC = {schema}\"{value}\""),
                 format!("/* {}::moving_state */", self.full_path),
             ));
         }
         if let Some(value) = self.minvfunc {
             optional_attributes.push((
-                format!("\tMINVFUNC = {}\"{}\"", schema, value),
+                format!("\tMINVFUNC = {schema}\"{value}\""),
                 format!("/* {}::moving_state_inverse */", self.full_path),
             ));
         }
         if let Some(value) = self.mfinalfunc {
             optional_attributes.push((
-                format!("\tMFINALFUNC = {}\"{}\"", schema, value),
+                format!("\tMFINALFUNC = {schema}\"{value}\""),
                 format!("/* {}::moving_state_finalize */", self.full_path),
             ));
         }
@@ -238,13 +238,13 @@ impl ToSql for PgAggregateEntity {
         }
         if let Some(value) = self.minitcond {
             optional_attributes.push((
-                format!("\tMINITCOND = '{}'", value),
+                format!("\tMINITCOND = '{value}'"),
                 format!("/* {}::MOVING_INITIAL_CONDITION */", self.full_path),
             ));
         }
         if let Some(value) = self.sortop {
             optional_attributes.push((
-                format!("\tSORTOP = \"{}\"", value),
+                format!("\tSORTOP = \"{value}\""),
                 format!("/* {}::SORT_OPERATOR */", self.full_path),
             ));
         }
@@ -290,7 +290,7 @@ impl ToSql for PgAggregateEntity {
         if let Some(value) = &self.mstype {
             let mstype_sql = map_ty(value).wrap_err("Mapping moving state type")?;
             optional_attributes.push((
-                format!("\tMSTYPE = {}", mstype_sql),
+                format!("\tMSTYPE = {mstype_sql}"),
                 format!("/* {}::MovingState = {} */", self.full_path, value.full_path),
             ));
         }
@@ -348,7 +348,7 @@ impl ToSql for PgAggregateEntity {
                        maybe_comma = if needs_comma { ", " } else { " " },
                        full_path = arg.used_ty.full_path,
                        name = if let Some(name) = arg.name {
-                           format!(r#""{}" "#, name)
+                           format!(r#""{name}" "#)
                        } else { "".to_string() },
                 );
                 args.push(buf);
