@@ -15,10 +15,9 @@ mod tests {
 
     #[pg_test]
     fn test_anyelement_arg() -> Result<(), pgrx::spi::Error> {
-        let element = Spi::get_one_with_args::<AnyElement>("SELECT anyelement_arg($1);", unsafe {
-            &[DatumWithOid::new(123, AnyElement::type_oid())]
-        })?
-        .map(|e| e.datum());
+        let oid = unsafe { DatumWithOid::new(123, AnyElement::type_oid()) };
+        let element = Spi::get_one_with_args::<AnyElement>("SELECT anyelement_arg($1);", &[oid])?
+            .map(|e| e.datum());
 
         assert_eq!(element, 123.into_datum());
 
