@@ -82,6 +82,11 @@ fn returns_none() -> Option<i32> {
     None
 }
 
+#[pg_extern]
+fn panics() -> Option<i32> {
+    panic!("an error message")
+}
+
 #[pg_extern]
 fn returns_null() -> Nullable<i32> {
     Nullable::Null
@@ -308,6 +313,14 @@ mod tests {
         assert!(result.is_none())
     }
 
+    #[pg_test]
+    unsafe fn test_panics() {
+        let r = std::panic::catch_unwind(|| {
+            direct_pg_extern_function_call::<i32>(super::panics_wrapper, &[])
+        });
+        assert!(r.is_err());
+    }
+
     #[pg_test]
     fn test_returns_void() {
         let result = Spi::get_one::<()>("SELECT returns_void();");
