@@ -18,7 +18,7 @@ fn extern_func() -> bool {
 // This ensures that parameterized function compiles when it has `pg_guard` attached to it
 #[pg_guard]
 // Uncommenting the line below will make it fail to compile
-// #[no_mangle]
+// #[unsafe(no_mangle)]
 extern "C-unwind" fn extern_func_impl<T>() -> bool {
     let _ = PhantomData::<T>;
     true
@@ -27,7 +27,7 @@ extern "C-unwind" fn extern_func_impl<T>() -> bool {
 // This ensures that non-parameterized function compiles when it has `pg_guard` attached to it
 // and [no_mangle]
 #[pg_guard]
-#[no_mangle]
+#[unsafe(no_mangle)]
 extern "C-unwind" fn extern_func_impl_1() -> bool {
     true
 }
@@ -35,7 +35,7 @@ extern "C-unwind" fn extern_func_impl_1() -> bool {
 // This ensures that lifetime-parameterized function compiles when it has `pg_guard` attached to it
 // and [no_mangle]
 #[pg_guard]
-#[no_mangle]
+#[unsafe(no_mangle)]
 #[allow(unused_lifetimes, clippy::extra_unused_lifetimes)]
 extern "C-unwind" fn extern_func_impl_2<'a>() -> bool {
     let _ = PhantomData::<&'a ()>;
